var map_sites_nearby;
angular.module('morganfuels', ['ionic', 'ngSanitize', 'morganfuels.controllers', 'morganfuels.services'])
.config(function ($stateProvider, $urlRouterProvider, $httpProvider) {
    $httpProvider.defaults.useXDomain = true;
    $stateProvider
    .state('home', { url: "/home", templateUrl: "home.html" })
    .state('sites-nearby', { url: "/sites-nearby", templateUrl: "sites-nearby.html" })
    .state('search-sites', { url: "/search-sites", templateUrl: "search-sites.html" })
    .state('sites-list-full', { url: "/sites-list-full", templateUrl: "sites-list-full.html" })
    .state('sites-list-search', { url: "/sites-list-search", templateUrl: "sites-list-search.html" })
    .state('full-site-list', { url: "/full-site-list", templateUrl: "full-site-list.html" })
    .state('settings', { url: "/settings", templateUrl: "settings.html" })
    .state('settings/price-classes', { url: "/settings/price-classes", templateUrl: "settings-price-classes.html" })
    .state('contact', { url: "/contact", templateUrl: "contact.html" })
    .state('privacy-policy', { url: "/privacy-policy", templateUrl: "privacy-policy.html" })
    .state('site-details', { url: "/site-details", templateUrl: "site-details.html" })
    .state('intro', { url: "/intro", templateUrl: "intro.html" })
    $urlRouterProvider.otherwise('/intro');
})
.directive('selectClick', function() {
    return {
        restrict: 'A',
        scope: true,
        controller: function($scope, $element) {
            $element.bind('click', function() {
                if(window.cordova) {
                    cordova.plugins.Keyboard.hideKeyboardAccessoryBar(false);
                }
            });
            var select = $element.find('select');
            select.bind('blur', function() {
                if(window.cordova) {
                    cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
                    cordova.plugins.Keyboard.hideKeyboardAccessoryBar(false);
                }
            });
        }
    }
})
.run(function ($ionicPlatform, $state, $ionicHistory, $ionicPopup, $ionicSideMenuDelegate) {
    $ionicPlatform.ready(function () {
        function _waitForAnalytics(){
            if(typeof analytics === 'object'){
                analytics.startTrackerWithId('UA-58298878-1');
            }
            else{
                setTimeout(function(){
                    _waitForAnalytics();
                }, 500);
            }
        };
        _waitForAnalytics();
        if (window.cordova && window.cordova.plugins.Keyboard) {
            cordova.plugins.Keyboard.hideKeyboardAccessoryBar(false);
            cordova.plugins.Keyboard.disableScroll(true);
        }
        if (window.StatusBar) {
            StatusBar.backgroundColorByHexString('#000000');
            StatusBar.styleLightContent();
        }
        document.addEventListener('menubutton', function(){
            $ionicSideMenuDelegate.toggleLeft();
        }, false);
        $ionicPlatform.registerBackButtonAction(function (e) {
            var back_action = false;
            switch($state.current.name) {
                case 'home' : back_action = 'do_exit'; break;
                case 'sites-nearby' : back_action = 'home'; break;
                case 'search-sites' : back_action = 'home'; break;
                case 'sites-list-full' : back_action = 'full-site-list'; break;
                case 'sites-list-search' : back_action = 'search-sites'; break;
                case 'full-site-list' : back_action = 'home'; break;
                case 'settings' : back_action = 'home'; break;
                case 'settings/price-classes' : back_action = 'settings'; break;
                case 'contact' : back_action = 'back'; break;
                case 'site-details' : back_action = 'back'; break;
            }
            if(back_action !== false) {
                if(back_action === 'do_exit') {
                    var confirm_exit = $ionicPopup.confirm({
                        title: 'Exit Application',
                        template: 'Are you sure you want to close Application?'
                    });
                    confirm_exit.then(function (close) {
                        if (close) {
                            if(typeof analytics === 'object'){
                                analytics.trackEvent('Exit', 'Exit Application');
                            }
                            ionic.Platform.exitApp();
                        }
                    });
                } else if(back_action === 'back') {
                    if($ionicHistory.backView()) {
                        $ionicHistory.goBack();
                    } else {
                        $state.go('home');
                    }
                } else {
                    $state.go(back_action);
                }
            } else {
                $state.go('home');
            }
        }, 100);
    });
});
angular.module('morganfuels.controllers', ['ionic', 'ngSanitize'])
.controller('App_Controller', function ($scope, $location, $ionicLoading, $ionicHistory, $ionicPopup) {
    $scope.go_back = function(view_default) {
        var back_view = $ionicHistory.backView();
        var current_view = $ionicHistory.currentView();
        if(back_view && typeof back_view == 'object' && back_view.stateName != current_view.stateName) {
            $ionicHistory.goBack();
        } else {
            if(view_default == undefined) {
                $location.path('home');
            } else {
                $location.path(view_default);
            }
        }
    };
    $scope.operating_system = 'android';
    if(ionic.Platform.isIOS()) {
        $scope.operating_system = 'ios';
    }
    $scope.is_android = function() {
        return ($scope.operating_system == 'android');
    };
    $scope.app_exit = function() {
        var confirm_exit = $ionicPopup.confirm({
            title: 'Exit Application',
            template: 'Are you sure you want to close Application?'
        });
        confirm_exit.then(function (close) {
            if (close) {
                if(typeof analytics === 'object'){
                    analytics.trackEvent('Exit', 'Exit Application');
                }
                ionic.Platform.exitApp();
            }
        });
    };
})
.controller('Home_Controller', function ($scope, $ionicHistory) {
    $ionicHistory.clearCache();
    $ionicHistory.clearHistory();
})
.controller('Intro_Controller', function ($scope, $location, $timeout) {
    if(typeof analytics === 'object'){
        analytics.trackView('Welcome');
    }
    $timeout(function () {
        $location.path('home');
    }, 1000);
})
.controller('Sites_Nearby_Controller', function ($scope, $settings, $ionicLoading, $location, $ionicPopup, morganfuels_api) {
    if(typeof analytics === 'object'){
        analytics.trackView('Sites Nearby');
    }
    $ionicLoading.hide();
    $ionicLoading.show({
        templateUrl: false,
        template: 'Getting Location<br /><img src="images/loader.gif" />',
        animation: 'no-animation',
        showDelay: 0,
        hideOnStateChange: true
    });
    $scope.coverage_points = [];
    navigator.geolocation.getCurrentPosition(
        function (position) {
            $scope.call_init_map(position.coords.latitude, position.coords.longitude);
        },
        function errorHandler(error) {
            switch(error.code) {
                case error.PERMISSION_DENIED:
                    $scope.error_message = 'Unable to get your location information. You denied the request for Geolocation.';
                    break;
                case error.POSITION_UNAVAILABLE:
                    $scope.error_message = 'Unable to get your location information. It seems that the location information is not available on your device.';
                    break;
                case error.TIMEOUT:
                    $scope.error_message = 'Unable to get your location information. You device is not responding. i.e. taking too long to respond.';
                    break;
                case error.UNKNOWN_ERROR:
                default:
                    $scope.error_message = 'Unable to get your location information. An unknown error occurred.';
                    break;                
            }
            $ionicLoading.hide();
            if($scope.error_message) {
                $ionicPopup.confirm({
                    title: '<b>Location Error</b>',
                    template: $scope.error_message,
                    scope: $scope,
                    buttons: [
                        {
                            text: '<i class="ion-chevron-left"></i> Go Back',
                            type: 'button-positive',
                            onTap: function(e) {
                                $scope.error_message = false;
                                $scope.go_back();
                            }
                        }
                    ]
                });
            }
        },
        {
            enableHighAccuracy: true,
            timeout: 30000,
            maximumAge: 0
        }
    );    
    $scope.call_init_map = function (latitude, longitude) {
        map_sites_nearby = plugin.google.maps.Map.getMap(
            document.getElementById('map_sites_nearby'),
            {
            'backgroundColor': 'white',
            'mapType': plugin.google.maps.MapTypeId.ROADMAP,
            'controls': {
                'compass': true,
                'myLocationButton': false,
                'indoorPicker': false,
                'zoom': true
            },
            'gestures': {
                'scroll': true,
                'tilt': true,
                'rotate': true
            },
            'camera': {
                'latLng': new plugin.google.maps.LatLng(latitude, longitude),
                'zoom' : 10,
                'duration' : 1000
            }
        });
        map_sites_nearby.on(plugin.google.maps.event.MAP_READY, function(position){
            if($scope.coverage_points.length > 0) {
                map_sites_nearby.animateCamera({
                    'target' : new plugin.google.maps.LatLngBounds($scope.coverage_points),
                    'duration' : 1000
                });
            } else {
                map_sites_nearby.animateCamera({
                    'zoom' : 10,
                    'latLng' : new plugin.google.maps.LatLng(latitude, longitude),
                    'duration' : 1000
                });
            }
        });
        map_sites_nearby.clear();
        var circle_radius = $settings.get('nearby_radius');
        if($settings.get('distance_unit') == 'km') {
            circle_radius = Math.round(circle_radius * 1000);
        } else {
            circle_radius = Math.round(circle_radius * 1609.34);
        }
        map_sites_nearby.addCircle({
            'center': new plugin.google.maps.LatLng(latitude, longitude),
            'radius': circle_radius,
            'strokeColor' : '#0032ab',
            'strokeWidth': 1,
            'fillColor' : 'transparent',
            'zIndex' : 0
        });
        map_sites_nearby.addMarker({
            'position': new plugin.google.maps.LatLng(latitude, longitude),
            'disableAutoPan': false,
            'icon' : 'www/images/icons/user.png',
            'title': 'Your Location',
            'styles' : {},
            'snippet': 'This is your location based on response by your device.'
        });
        $scope.call_add_marker(latitude, longitude);
    };     
    $scope.call_add_marker = function (latitude, longitude) {    
        $ionicLoading.show({
            templateUrl: false,
            template: 'Loading Sites<br /><img src="images/loader.gif" />',
            animation: 'no-animation',
            showDelay: 0,
            hideOnStateChange: true
        });
        var obj_sites = morganfuels_api.get_sites_nearby(latitude, longitude);
        obj_sites.error(function (response, status, headers, config){
            $ionicLoading.hide();
        });    
        obj_sites.success(function (response, status, headers, config) {
            if(response.data && response.data.length > 0) {
               $scope.coverage_points = [];
               $scope.coverage_points.push(new plugin.google.maps.LatLng(latitude, longitude)); //XXX
               angular.forEach(response.data, function(value, key) {
                    map_sites_nearby.addMarker({
                        'position': new plugin.google.maps.LatLng(value.latitude, value.longitude),
                        'disableAutoPan': false,
                        'icon' : 'www/images/icons/'+value.price_class+'.png',
                        'title': value.name,
                        'styles' : {},
                        'snippet': value.address + "\n\r" + value.approx_distance,
                        'site_id': value.id,
                        'infoClick': function(marker) {
                            $location.path('site-details').search({
                                id: marker.get('site_id')
                            });
                            if(!$scope.$$phase) {
                                $scope.$apply();
                            }
                        }
                    });
                    $scope.coverage_points.push(new plugin.google.maps.LatLng(value.latitude, value.longitude));
                });
                map_sites_nearby.animateCamera({
                    'target' : new plugin.google.maps.LatLngBounds($scope.coverage_points),
                    'duration' : 1000
                });                   
            } else {
                $scope.error_message = 'No sites found around your current location. You can increase radius distance under settings and retry.';
            }
            $ionicLoading.hide();
        });
    };    
})
.controller('Contact_Controller', function ($scope, $ionicLoading, morganfuels_api) {
    if(typeof analytics === 'object'){
        analytics.trackView('Contact');
    }
    $ionicLoading.hide();    
    $ionicLoading.show({
        templateUrl: false,
        template: 'Loading Information<br /><img src="images/loader.gif" />',
        animation: 'no-animation',
        showDelay: 0,
        hideOnStateChange: true
    });
    var static_contact = '<p><strong>Morgan Fuel &amp; Lubes Ltd</strong><br />254 Dublin Road<br />Killean<br />Newry<br />Co. Down<br />Free Phone : <a href="tel:08003287899">0800 328 7899</a><br />Tel Intl : <a href="tel:+442830848365">+44 2830 848 365</a> </p><hr noshade="noshade" size="1" /><p> <strong>Morgan Fuels Ireland Ltd</strong><br />Carrickcarnon<br />Ravensdale<br />Dundalk<br />Co Louth Free Phone : <a href="tel:1800444447">1800 444 447</a><br />Tel Intl : <a href="tel:+442830848365">+44 2830 848 365</a> </p><hr noshade="noshade" size="1" /><p><strong>E-mail</strong> : <a href="mailto:info@morganfuels.com">info@morganfuels.com</a></p><hr noshade="noshade" size="1" /><p>Phone lines are open <em>Monday</em> to <em>Friday</em> from <em>8.30 am</em> to <em>5.30 pm</em></p>';
    var obj_contact = morganfuels_api.get_contact();
    obj_contact.error(function (response, status, headers, config){
        $scope.contact_info = static_contact;
        $ionicLoading.hide();
    });    
    obj_contact.success(function (response, status, headers, config) {
        if(response.status == 1) {
            $scope.contact_info = '';
            if(response.data && typeof response.data == 'string') {
                $scope.contact_info = response.data;
            } else {
                $scope.contact_info = static_contact;
            }
        } else {
            $scope.contact_info = static_contact;
        }
        $ionicLoading.hide();
    });
})
.controller('Privacy_Policy_Controller', function ($scope, $ionicLoading, morganfuels_api) {
    if(typeof analytics === 'object'){
        analytics.trackView('Privacy Policy');
    }
    $ionicLoading.hide();    
    $ionicLoading.show({
        templateUrl: false,
        template: 'Loading Information<br /><img src="images/loader.gif" />',
        animation: 'no-animation',
        showDelay: 0,
        hideOnStateChange: true
    });
    var static_privacy_policy = '<p>This privacy policy governs your use of the software application <em>Morgan Fuels</em> (&ldquo;Application&rdquo;) for mobile devices that was created by <em>RK Marketing Ltd</em>. The Application provides different options to search our fuel re-filling sites around Europe and world. Users can get information about sites nearby to the current location of the Application user, search sites by enter Postcode or Town name &amp; also by select country/county names etc. Users can call their mobile device\'s native Maps app to get route information from their current location to selected site.</p><h2>What information does the Application obtain and how is it used?</h2><p>The Application may automatically collect certain information automatically, including, but not limited to, the type of mobile device you use, your mobile devices unique device ID, the IP address of your mobile device, your mobile operating system, the type of mobile Internet browsers you use, and information about the way you use the Application. We may store your preferences/settings information locally on your device using mechanisms such as web storage and application data caches.</p><h2>The Application collect precise real time location information of the device</h2><p>When you visit the mobile application, we may use GPS technology (or other similar technology) to determine your current location in order to determine the city you are located within and display distance information with sites. We will not share your current location with other users or partners.</p><p>If you do not want us to use your location for the purposes set forth above, you should turn off the location services for the mobile application located in your account settings or in your mobile phone settings and/or within the mobile application.</p><h2>Do third parties see and/or have access to information obtained by the Application?</h2><p>Yes. We will share your information with third parties only in the ways that are described in this privacy statement. We may disclose User Provided and Automatically Collected Information:</p><ul><li>as required by law, such as to comply with a subpoena, or similar legal process;</li><li>when we believe in good faith that disclosure is necessary to protect our rights, protect your safety or the safety of others, investigate fraud, or respond to a government request;</li><li>With our trusted services providers who work on our behalf, do not have an independent use of the information we disclose to them, and have agreed to adhere to the rules set forth in this privacy statement.</li><li>If <em>RK Marketing Ltd</em> is involved in a merger, acquisition, or sale of all or a portion of its assets, you will be notified via email and/or a prominent notice on our Web site of any change in ownership or uses of this information, as well as any choices you may have regarding this information.</li></ul><h2>What are my opt-out rights?</h2><p>You can stop all collection of information by the Application easily by uninstalling the Application. You may use the standard uninstall processes as may be available as part of your mobile device or via the mobile application marketplace or network.</p><h2>Data Retention Policy, Managing Your Information</h2><p>We will retain User Provided data for as long as you use the Application and for a reasonable time thereafter. We will retain Automatically Collected information for up to 24 months and thereafter may store it in aggregate. If you&rsquo;d like us to delete User Provided Data that you have provided via the Application, please contact us at <em>info@morganfuels.com</em> and we will respond in a reasonable time. Please note that some or all of the User Provided Data may be required in order for the Application to function properly.</p><h2>Security</h2><p>We are concerned about safeguarding the confidentiality of your information. We provide physical, electronic, and procedural safeguards to protect information we process and maintain. For example, we limit access to this information to authorized employees and contractors who need to know that information in order to operate, develop or improve our Application. Please be aware that, although we endeavour provide reasonable security for information we process and maintain, no security system can prevent all potential security breaches.</p><h2>Changes</h2><p>This Privacy Policy may be updated from time to time for any reason. We will notify you of any changes to our Privacy Policy by posting the new Privacy Policy here and informing you via notification while you will be using Application. You are advised to consult this Privacy Policy regularly for any changes, as continued use is deemed approval of all changes.</p><h2>Your Consent</h2><p>By using the Application, you are consenting to our processing of your information as set forth in this Privacy Policy now and as amended by us. &quot;Processing&quot;, means using cookies on a computer/hand held device or using or touching information in any way, including, but not limited to, collecting, storing, deleting, using, combining and disclosing information, all of which activities will take place in the <em>United Kingdom</em>. If you reside outside the <em>United Kingdom</em> your information will be transferred, processed and stored there under <em>United Kingdom</em> privacy standards.</p><h2>Contact us</h2><p>If you have any questions regarding privacy while using the Application, or have questions about our practices, please contact us via email at <em>info@morganfuels.com</em>.</p>';
    var obj_privacy_policy = morganfuels_api.get_privacy_policy();
    obj_privacy_policy.error(function (response, status, headers, config){
        $scope.privacy_policy_info = static_privacy_policy;
        $ionicLoading.hide();
    });    
    obj_privacy_policy.success(function (response, status, headers, config) {
        if(response.status == 1) {
            $scope.privacy_policy_info = '';
            if(response.data && typeof response.data == 'string') {
                $scope.privacy_policy_info = response.data;
            } else {
                $scope.privacy_policy_info = static_privacy_policy;
            }
        } else {
            $scope.privacy_policy_info = static_privacy_policy;
        }
        $ionicLoading.hide();
    });
})
.controller('Sites_List_Full_Controller', function ($scope, $ionicLoading, $location, $settings, $ionicPopup, morganfuels_api) {
    if(typeof analytics === 'object'){
        analytics.trackView('Full Site List - Sites List');
    }
    $ionicLoading.hide();
    $scope.call_init_full_site_list = function(latitude, longitude) {    
        $ionicLoading.show({
            templateUrl: false,
            template: 'Searching Sites<br /><img src="images/loader.gif" />',
            animation: 'no-animation',
            showDelay: 0,
            hideOnStateChange: true
        });    
        var query = $location.search();
        if(typeof analytics === 'object'){
            analytics.trackEvent('Full Site List - Sites List', query.country + ', ' + query.county);
        }
        var obj_sites = morganfuels_api.full_site_list(query.country, query.county, latitude, longitude);        
        obj_sites.error(function (response, status, headers, config){
            $ionicLoading.hide();
            $ionicPopup.confirm({
                title: '<b>Network Error!</b>',
                template: 'Unexpected error detracted. It seems that your internet connection is not working or data server is experiencing some problem at the moment. Go back &amp; retry.',
                scope: $scope,
                buttons: [
                    {
                        text: '<i class="ion-chevron-left"></i> Go Back',
                        type: 'button-positive',
                        onTap: function(e) {
                            $scope.go_back();
                        }
                    }
                ]
            });
        });    
        obj_sites.success(function (response, status, headers, config) {
            if(response.status == 1) {
                $scope.sites = [];
                if(response.data && response.data.length > 0) {
                    angular.forEach(response.data, function(value, key) {
                        $scope.sites[key] = value;
                    });
                } else {
                    $ionicPopup.confirm({
                        title: '<b>No Sites Found</b>',
                        template: 'No sites found, in response to your selected country/county.',
                        scope: $scope,
                        buttons: [
                            {
                                text: '<i class="ion-chevron-left"></i> Go Back',
                                type: 'button-positive',
                                onTap: function(e) {
                                    $scope.go_back();
                                }
                            }
                        ]
                    });
                }
                $ionicLoading.hide();
            }
        });
    };
    
    if($settings.get('display_distance')) {
    
        $ionicLoading.show({
            templateUrl: false,
            template: 'Getting Location<br /><img src="images/loader.gif" />',
            animation: 'no-animation',
            showDelay: 0,
            hideOnStateChange: true
        });
    
        navigator.geolocation.getCurrentPosition(
            function (position) {
                $scope.call_init_full_site_list(position.coords.latitude, position.coords.longitude);
            },
            function errorHandler(error) {
                $scope.call_init_full_site_list(0, 0);
            },
            {
                enableHighAccuracy: true,
                timeout: 30000,
                maximumAge: 0
            }
        );  
    } else {
        $scope.call_init_full_site_list(0, 0);
    }
})
.controller('Sites_List_Search_Controller', function ($scope, $ionicLoading, $settings, $location, $ionicPopup, morganfuels_api) {  
    if(typeof analytics === 'object'){
        analytics.trackView('Search Sites - Sites List');
    }
    $ionicLoading.hide();
    $scope.call_init_full_site_list = function(latitude, longitude) {    
        $ionicLoading.show({
            templateUrl: false,
            template: 'Searching Sites<br /><img src="images/loader.gif" />',
            animation: 'no-animation',
            showDelay: 0,
            hideOnStateChange: true
        });    
        var query = $location.search();    
        if(typeof analytics === 'object'){
            if(typeof query.postcode === 'string' && query.postcode !== '') {
                analytics.trackEvent('Search Sites - Sites List', 'Postcode: ' + query.postcode);
            }
            if(typeof query.site_name === 'string' && query.site_name !== '') {
                analytics.trackEvent('Search Sites - Sites List', 'Town: ' + query.site_name);
            }
        }
        var obj_sites = morganfuels_api.search_sites(query.postcode, query.site_name, latitude, longitude);        
        obj_sites.error(function (response, status, headers, config){
            $ionicLoading.hide();
            $ionicPopup.confirm({
                title: '<b>Network Error!</b>',
                template: 'Unexpected error detracted. It seems that your internet connection is not working or data server is experiencing some problem at the moment. Go back &amp; retry.',
                scope: $scope,
                buttons: [
                    {
                        text: '<i class="ion-chevron-left"></i> Go Back',
                        type: 'button-positive',
                        onTap: function(e) {
                            $scope.go_back();
                        }
                    }
                ]
            });
        });    
        obj_sites.success(function (response, status, headers, config) {
            if(response.status == 1) {
                $scope.sites = [];
                if(response.data && response.data.length > 0) {
                    angular.forEach(response.data, function(value, key) {
                        $scope.sites[key] = value;
                    });
                } else {
                    $ionicPopup.confirm({
                        title: '<b>No Sites Found</b>',
                        template: 'No sites found, in response to your input for postcode and/or town name.',
                        scope: $scope,
                        buttons: [
                            {
                                text: '<i class="ion-chevron-left"></i> Go Back',
                                type: 'button-positive',
                                onTap: function(e) {
                                    $scope.go_back();
                                }
                            }
                        ]
                    });
                }
                $ionicLoading.hide();
            }
        });
    };
    
    if($settings.get('display_distance')) {
    
        $ionicLoading.show({
            templateUrl: false,
            template: 'Getting Location<br /><img src="images/loader.gif" />',
            animation: 'no-animation',
            showDelay: 0,
            hideOnStateChange: true
        });
    
        navigator.geolocation.getCurrentPosition(
            function (position) {
                $scope.call_init_full_site_list(position.coords.latitude, position.coords.longitude);
            },
            function errorHandler(error) {
                $scope.call_init_full_site_list(0, 0);
            },
            {
                enableHighAccuracy: true,
                timeout: 30000,
                maximumAge: 0
            }
        );  
    } else {
        $scope.call_init_full_site_list(0, 0);
    }
})
.controller('Search_Sites_Controller', function ($scope, $ionicLoading, $location, $ionicPopup) {
    if(typeof analytics === 'object'){
        analytics.trackView('Search Sites');
    }
    $ionicLoading.hide();
    $scope.submit_search_site = function(postcode, site_name){
        if(window.cordova && window.cordova.plugins.Keyboard) {
            cordova.plugins.Keyboard.close();
        }
        if(postcode) {
            postcode = postcode.trim();
        }
        if(site_name) {
            site_name = site_name.trim();
        }
        if((postcode == undefined || postcode == '') && (site_name == undefined || site_name == '')) {
            $ionicPopup.alert({
                title: '<b>Error!</b>',
                template: 'Please enter Postcode and/or Town Name.'
            });
        } else {
            $location.path('sites-list-search').search({
                postcode: postcode,
                site_name: site_name
            });
        }
    }
})
.controller('Full_Site_List_Controller', function ($scope, $ionicLoading, $location, $ionicPopup, morganfuels_api) {    
    if(typeof analytics === 'object'){
        analytics.trackView('Full Site List');
    }
    $ionicLoading.hide();    
    $ionicLoading.show({
        templateUrl: false,
        template: 'Loading Countries<br /><img src="images/loader.gif" />',
        animation: 'no-animation',
        showDelay: 0,
        hideOnStateChange: true
    });    
    var obj_countries = morganfuels_api.get_countries();
    obj_countries.error(function (response, status, headers, config){
        $ionicLoading.hide();
        $ionicPopup.confirm({
            title: '<b>Network Error!</b>',
            template: 'Unexpected error detracted. It seems that your internet connection is not working or data server is experiencing some problem at the moment. Go back &amp; retry.',
            scope: $scope,
            buttons: [
                {
                    text: '<i class="ion-chevron-left"></i> Go Back',
                    type: 'button-positive',
                    onTap: function(e) {
                        $scope.go_back();
                    }
                }
            ]
        });
    });
    obj_countries.success(function (response, status, headers, config) {
        if(response.status == 1) {
            $scope.countries = [];
            if(response.data) {
                angular.forEach(response.data, function(value, key) {
                    $scope.countries[key] = value;
                });
            } else {
                $scope.countries.push({
                    id: 0,
                    name: 'No Countries Found'
                });
            }
            $scope.country_model = $scope.countries[0].id;
            $ionicLoading.hide();
        } else {
            $scope.countries.push({
                id: 0,
                name: 'No Countries Found'
            });
            $scope.country_model = $scope.countries[0].id;
        }
    });
    $scope.change_country = function(country) {
        if(country == 0) return;        
        $ionicLoading.show({
            templateUrl: false,
            template: 'Loading Counties<br /><img src="images/loader.gif" />',
            animation: 'no-animation',
            showDelay: 0,
            hideOnStateChange: true
        });        
        var obj_counties = morganfuels_api.get_counties(country);
        obj_counties.error(function (response, status, headers, config){
            $ionicLoading.hide();
            $ionicPopup.confirm({
                title: '<b>Network Error!</b>',
                template: 'Unexpected error detracted. It seems that your internet connection is not working or data server is experiencing some problem at the moment. Go back &amp; retry.',
                scope: $scope,
                buttons: [
                    {
                        text: '<i class="ion-chevron-left"></i> Go Back',
                        type: 'button-positive',
                        onTap: function(e) {
                            $scope.go_back();
                        }
                    }
                ]
            });
        });        
        obj_counties.success(function (response, status, headers, config) {
            if(response.status == 1) {
                $scope.counties = [];
                if(response.data) {
                    angular.forEach(response.data, function(value, key) {
                        $scope.counties[key] = value;
                        if(response.data.length == 1) {
                           $scope.submit_view_list(country, value.id);
                        }
                    });
                } else {
                    $scope.counties.push({
                        id: 0,
                        name: 'No Counties Found'
                    });
                }
                $scope.county_model = $scope.counties[0].id;
                $ionicLoading.hide();
            }
        });
    };    
    $scope.submit_view_list = function(country, county) {        
        if(country == undefined || country == 0) {
            $ionicPopup.alert({
                title: '<b>Error!</b>',
                template: 'Please select Country.'
            });            
        } else if(county == undefined || county == 0) {
            $ionicPopup.alert({
                title: '<b>Error!</b>',
                template: 'Please select County.'
            });
        } else {        
            $location.path('sites-list-full').search({
                country: country,
                county: county
            });
        }
    }
})
.controller('Settings_Controller', function ($scope, $settings) {
    if(typeof analytics === 'object'){
        analytics.trackView('Settings');
    }
    $scope.sites_24_hour_model = $settings.get('sites_24_hour');    
    $scope.vehicle_classes_model = $settings.get('vehicle_class_selected');
    $scope.options_vehicle_classes = [];
    angular.forEach($settings.options('vehicle_classes'), function(value, key) {
        $scope.options_vehicle_classes[key] = {
            id: value,
            name: value,
            selected: ($scope.vehicle_classes_model == value)
        };
    });    
    $scope.display_distance_model = $settings.get('display_distance');    
    $scope.distance_unit_model = $settings.get('distance_unit');
    $scope.options_distance_units = [];
    angular.forEach($settings.options('distance_units'), function(value, key) {
        $scope.options_distance_units[key] = {
            id: value.id,
            name: value.name,
            selected: ($scope.distance_unit_model == value.id)
        };
    });
    $scope.unit_text = $scope.distance_unit_model;    
    $scope.nearby_radius_model = $settings.get('nearby_radius');
    $scope.options_nearby_radius = [];
    angular.forEach($settings.options('nearby_radius'), function(value, key) {
        $scope.options_nearby_radius[key] = {
            id: value,
            name: value,
            selected: ($scope.nearby_radius_model == value)
        };
    });    
    $scope.change_sites_24_hour = function(checked) {
        $settings.set('sites_24_hour', checked);
    };    
    $scope.change_vehicle_classes = function(vehicle_class){
        $settings.set('vehicle_class_selected', vehicle_class);
    };    
    $scope.change_display_distance = function(checked) {
        $settings.set('display_distance', checked);
    };    
    $scope.change_distance_unit = function(unit) {
        $settings.set('distance_unit', unit);
        $scope.unit_text = unit;
    };
    $scope.change_nearby_radius = function(radius) {
        $settings.set('nearby_radius', radius);
    };
})
.controller('Settings_Price_Classes_Controller', function ($scope, $settings) {
    if(typeof analytics === 'object'){
        analytics.trackView('Settings - Price Classes');
    }
    $scope.price_class_all_model = $settings.get('price_class_all');
    $scope.price_class_selected = $settings.get('price_class_selected');
    $scope.options_price_classes = [];
    angular.forEach($settings.options('price_classes'), function(value, key) {
        $scope.options_price_classes[key] = {
            name: value,
            checked: ($scope.price_class_selected.indexOf(value) > -1)            
        };
    });    
    $scope.change_price_class_all = function(checked) {
        $settings.set('price_class_all', checked);
    }    
    $scope.change_price_class_selected = function(checked, price_class) {
        if(typeof $scope.price_class_selected == 'string') {
            $scope.price_class_selected = $scope.price_class_selected.split(',');
        }
        var index = $scope.price_class_selected.indexOf(price_class);
        if(checked == true) {
            if(index == -1) {
                $scope.price_class_selected.push(price_class);
            }
        } else {
            if(index != -1) {
                $scope.price_class_selected.splice(index, 1);
            }
        }
        $settings.set('price_class_selected', $scope.price_class_selected.sort());
    };    
})
.controller('Site_Details_Controller', function ($scope, $ionicLoading, $location, $ionicPopup, morganfuels_api) {
    if(typeof analytics === 'object'){
        analytics.trackView('Site Details');
    }
    $ionicLoading.hide();    
    $ionicLoading.show({
        templateUrl: false,
        template: 'Loading Info<br /><img src="images/loader.gif" />',
        animation: 'no-animation',
        showDelay: 0,
        hideOnStateChange: true
    });    
    var query = $location.search();    
    var obj_site = morganfuels_api.get_site(query.id);    
    obj_site.error(function (response, status, headers, config){
        $ionicLoading.hide();
        $ionicPopup.confirm({
            title: '<b>Network Error!</b>',
            template: 'Unexpected error detracted. It seems that your internet connection is not working or data server is experiencing some problem at the moment. Go back &amp; retry.',
            scope: $scope,
            buttons: [
                {
                    text: '<i class="ion-chevron-left"></i> Go Back',
                    type: 'button-positive',
                    onTap: function(e) {
                        $scope.go_back();
                    }
                }
            ]
        });
    });    
    obj_site.success(function (response, status, headers, config) {
        if(response.status == 1) {
            $scope.site = false;
            $ionicLoading.hide();
            if(response.data && typeof response.data == 'object' && response.data.id != undefined) {
                $scope.site = response.data;
            } else {
                $ionicPopup.confirm({
                    title: '<b>Site Not Found</b>',
                    template: 'Site details not found.',
                    scope: $scope,
                    buttons: [
                        {
                            text: '<i class="ion-chevron-left"></i> Go Back',
                            type: 'button-positive',
                            onTap: function(e) {
                                $scope.go_back();
                            }
                        }
                    ]
                });
            }
        }
    });    
    $scope.route_to_site = function(latitude, longitude) {
        if(typeof analytics === 'object'){
            analytics.trackEvent('Site Details', 'Route To Site');
        }
        $ionicLoading.hide();
        $ionicLoading.show({
            templateUrl: false,
            template: 'Getting Location<br /><img src="images/loader.gif" />',
            animation: 'no-animation',
            showDelay: 0,
            hideOnStateChange: true
        });
        navigator.geolocation.getCurrentPosition(
            function (position) {
                $ionicLoading.hide();
                plugin.google.maps.external.launchNavigation({
                    'from' : new plugin.google.maps.LatLng(position.coords.latitude, position.coords.longitude),
                    'to' : new plugin.google.maps.LatLng(latitude, longitude)
                });
            },
            function errorHandler(error) {
                $ionicLoading.hide();
                switch(error.code) {
                    case error.PERMISSION_DENIED:
                        $scope.error_message = 'Unable to get your location information. You denied the request for Geolocation.';
                        break;
                    case error.POSITION_UNAVAILABLE:
                        $scope.error_message = 'Unable to get your location information. It seems that the location information is not available on your device.';
                        break;
                    case error.TIMEOUT:
                        $scope.error_message = 'Unable to get your location information. You device is not responding. i.e. taking too long to respond.';
                        break;
                    case error.UNKNOWN_ERROR:
                    default:
                        $scope.error_message = 'Unable to get your location information. An unknown error occurred.';
                        break;                
                }
                if($scope.error_message) {
                    $ionicPopup.alert({
                        title: '<b>Location Error</b>',
                        template: $scope.error_message
                    });
                }
            },
            {
                enableHighAccuracy: true,
                timeout: 30000,
                maximumAge: 0
            }
        );
    };
});
angular.module('morganfuels.services', [])
.factory('$settings', function () {
    var configuration = window.localStorage['configuration'];
    var select_options = {
        vehicle_classes: ['All', 'HGV', 'LCV'],
        distance_units: [
            { name: 'Miles', id: 'mi.' },
            { name: 'Kilometres', id: 'km'}
        ],
        nearby_radius: [5, 10, 20, 50, 100],        
        price_classes: ['Q1', 'Q2', 'Q3', 'Q4', 'Q5', 'Q6', 'Q7', 'Q8', 'Q9', 'Q10']
    };    
    if(configuration != undefined) {
        configuration = JSON.parse(configuration);
    } else {
        configuration = {
            sites_24_hour : false,
            vehicle_class_selected: 'All',
            distance_unit: 'km',
            display_distance : true,
            price_class_all: true,
            price_class_selected: [],
            nearby_radius: 20
        };        
        window.localStorage['configuration'] = JSON.stringify(configuration);
    };    
    return {    
        options : function(key) {
            if(select_options.hasOwnProperty(key)) {
                return select_options[key];
            }
            return false;
        },    
        get : function(key) {
            if(configuration.hasOwnProperty(key)) {
                return configuration[key];
            }
            return false;
        },        
        set : function(key, value) {
            configuration[key] = value;
            window.localStorage['configuration'] = JSON.stringify(configuration);
        }
    };
})
.factory('morganfuels_api', function ($http, $settings, $window) {
    var api_server = 'https://www.morganfuels.com/api/';
    var api_version = '1.1';
    var fuel_card_id = 'u708284';
    return {    
        get_sites_nearby: function (latitude, longitude) {
            var price_class_selected = $settings.get('price_class_selected');        
            if(typeof price_class_selected != 'string') {
                price_class_selected = price_class_selected.join();
            }   
            return $http.get(api_server + api_version + '/sites-nearby.json', {
                cache: true,
                timeout: 30000,
                params: {
                    fuel_card_id: fuel_card_id,
                    latitude: latitude,
                    longitude: longitude,
                    sites_24_hour : $settings.get('sites_24_hour'),
                    vehicle_class_selected: $settings.get('vehicle_class_selected'),
                    distance_unit: $settings.get('distance_unit'),
                    display_distance : $settings.get('display_distance'),
                    price_class_all: $settings.get('price_class_all'),
                    price_class_selected: price_class_selected,
                    nearby_radius: $settings.get('nearby_radius')
                }
            });
        },
        get_contact: function () {        
            return $http.get(api_server + api_version + '/contact.json', {
                cache: true,
                timeout: 30000,
                params: {
                    fuel_card_id: fuel_card_id
                }
            });
        },
        get_privacy_policy: function () {        
            return $http.get(api_server + api_version + '/privacy-policy.json', {
                cache: true,
                timeout: 30000,
                params: {
                    fuel_card_id: fuel_card_id
                }
            });
        },
        get_site: function (site_id) {
            return $http.get(api_server + api_version + '/site.json', {
                cache: true,
                timeout: 30000,
                params: {
                    fuel_card_id: fuel_card_id,
                    site_id: site_id
                }
            });
        },
        get_countries: function () {        
            return $http.get(api_server + api_version + '/countries.json', {
                cache: true,
                timeout: 30000,
                params: {
                    fuel_card_id: fuel_card_id
                }
            });
        },        
        get_counties: function (country) {        
            return $http.get(api_server + api_version + '/counties.json', {
                cache: true,
                timeout: 30000,
                params: {
                    fuel_card_id: fuel_card_id,
                    country: country
                }
            });
        },        
        full_site_list: function (country, county, latitude, longitude) {
            var price_class_selected = $settings.get('price_class_selected');        
            if(typeof price_class_selected != 'string') {
                price_class_selected = price_class_selected.join();
            }        
            return $http.get(api_server + api_version + '/full-site-list.json', {
                cache: true,
                timeout: 30000,
                params: {
                    fuel_card_id: fuel_card_id,
                    country: country,
                    county: county,
                    latitude: latitude,
                    longitude: longitude,
                    sites_24_hour : $settings.get('sites_24_hour'),
                    vehicle_class_selected: $settings.get('vehicle_class_selected'),
                    distance_unit: $settings.get('distance_unit'),
                    display_distance : $settings.get('display_distance'),
                    price_class_all: $settings.get('price_class_all'),
                    price_class_selected: price_class_selected,
                    nearby_radius: $settings.get('nearby_radius')
                }
            });
        },        
        search_sites: function (postcode, name, latitude, longitude) {
            postcode = (postcode) ? encodeURI(postcode.trim()) : '';            
            name = (name) ? encodeURI(name.trim()) : '';
            var price_class_selected = $settings.get('price_class_selected');
            if(typeof price_class_selected != 'string') {
                price_class_selected = price_class_selected.join();
            }        
            return $http.get(api_server + api_version + '/search-sites.json', {
                cache: true,
                timeout: 30000,
                params: {
                    fuel_card_id: fuel_card_id,
                    postcode: postcode,
                    name: name,
                    latitude: latitude,
                    longitude: longitude,
                    sites_24_hour : $settings.get('sites_24_hour'),
                    vehicle_class_selected: $settings.get('vehicle_class_selected'),
                    distance_unit: $settings.get('distance_unit'),
                    display_distance : $settings.get('display_distance'),
                    price_class_all: $settings.get('price_class_all'),
                    price_class_selected: price_class_selected,
                    nearby_radius: $settings.get('nearby_radius')
                }
            });
        }
    };
});